pub struct DcAuthTracker { /* private fields */ }Expand description
State that must live inside ClientInner to track which DCs already have
a copy of the account’s authorization key.
Implementations
Sourceimpl DcAuthTracker
impl DcAuthTracker
pub fn new() -> Self
Sourcepub fn has_copied(&self, dc_id: i32) -> bool
pub fn has_copied(&self, dc_id: i32) -> bool
Check if we have already copied auth to dc_id.
Sourcepub fn mark_copied(&self, dc_id: i32)
pub fn mark_copied(&self, dc_id: i32)
Mark dc_id as having received a copy of the auth.