Module transport_intermediate

Module transport_intermediate 

MTProto Intermediate and Full transport framing.

Alongside the existing Abridged transport this module provides:

  • IntermediateTransport โ€” each packet is [4-byte LE length][payload]. More compatible than Abridged with proxies that inspect the first byte.

  • FullTransport โ€” like Intermediate but additionally includes a running sequence number and a CRC-32 checksum for integrity verification.

Structs

FullTransport
MTProto Full transport framing.
IntermediateTransport
MTProto Intermediate transport framing.