#[non_exhaustive]pub enum Update {
NewMessage(IncomingMessage),
MessageEdited(IncomingMessage),
MessageDeleted(MessageDeletion),
CallbackQuery(CallbackQuery),
InlineQuery(InlineQuery),
InlineSend(InlineSend),
Raw(RawUpdate),
}Expand description
A high-level event received from Telegram.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NewMessage(IncomingMessage)
A new message (personal chat, group, channel, or bot command).
MessageEdited(IncomingMessage)
An existing message was edited.
MessageDeleted(MessageDeletion)
One or more messages were deleted.
CallbackQuery(CallbackQuery)
An inline keyboard button was pressed on a bot message.
InlineQuery(InlineQuery)
A user typed an inline query for the bot.
InlineSend(InlineSend)
A user chose an inline result and sent it (bots only).
Raw(RawUpdate)
A raw TL update not mapped to any of the above variants.