pub struct Button { /* private fields */ }Expand description
A single inline keyboard button.
Implementations
Sourceimpl Button
impl Button
Sourcepub fn callback(text: impl Into<String>, data: impl Into<Vec<u8>>) -> Self
pub fn callback(text: impl Into<String>, data: impl Into<Vec<u8>>) -> Self
A button that sends a callback data payload when pressed.
Sourcepub fn url(text: impl Into<String>, url: impl Into<String>) -> Self
pub fn url(text: impl Into<String>, url: impl Into<String>) -> Self
A button that opens a URL in the browser.
Sourcepub fn url_auth(
text: impl Into<String>,
url: impl Into<String>,
fwd_text: Option<String>,
bot: InputUser,
) -> Self
pub fn url_auth( text: impl Into<String>, url: impl Into<String>, fwd_text: Option<String>, bot: InputUser, ) -> Self
A button that opens a user-profile or bot link in Telegram.
Sourcepub fn switch_inline(text: impl Into<String>, query: impl Into<String>) -> Self
pub fn switch_inline(text: impl Into<String>, query: impl Into<String>) -> Self
A button that switches to inline mode in the current chat.
Sourcepub fn text(label: impl Into<String>) -> Self
pub fn text(label: impl Into<String>) -> Self
A plain text button (for reply keyboards, not inline).
Sourcepub fn into_raw(self) -> KeyboardButton
pub fn into_raw(self) -> KeyboardButton
Consume into the raw TL type.