Update gap detection and recovery via updates.getDifference.
The Telegram MTProto protocol assigns a monotonically-increasing sequence
number called pts (and qts for secret chats, seq for the
combined updates container) to each update. If the client misses updates
(due to a disconnect, lag, or packet loss) the pts will jump forward. This
module tracks the current pts and fetches any missed updates via
updates.getDifference when a gap is detected.
Structs
- PtsState
- Tracks MTProto sequence numbers so we can detect and fill update gaps.