pub struct ObfuscatedStream { /* private fields */ }Expand description
Wraps a TcpStream with obfuscated MTProto2 framing.
After construction the initial 64-byte header has already been sent and the stream is ready for abridged MTProto messages.
Implementations
Sourceimpl ObfuscatedStream
impl ObfuscatedStream
Sourcepub async fn connect(
addr: &str,
proxy_secret: Option<&[u8; 16]>,
) -> Result<Self, InvocationError>
pub async fn connect( addr: &str, proxy_secret: Option<&[u8; 16]>, ) -> Result<Self, InvocationError>
Connect to addr and perform the obfuscated handshake.
proxy_secret is the MTProxy secret (32 bytes hex-decoded). Pass
None / zeros to use plain obfuscation without a proxy secret.